@@ -145,7 +145,7 @@ class WebsupportAPI:
         # return record[0]['id'] if len(record) == 1 and type(record) == list else None
 
     def handle_wildcard_auth(self, domain_name, validation_token):
-        subdomain = domain_name.replace(f".{self.domain}", "")
+        subdomain = domain_name.split(".")[0]
         # id_ = self.get_record_id(type_="TXT", name=subdomain)
         self.create_record(type_="TXT", name=subdomain, content=validation_token)
 
@@ -155,10 +155,6 @@ class WebsupportAPI:
         #     self.edit_record(id_=id_, content=validation_token)
 
     def clean_wildcard_auth(self, domain_name):
-        subdomain = domain_name.replace(f".{self.domain}", "")
+        subdomain = domain_name.split(".")[0]
         id_ = self.get_record_id("TXT", subdomain)
         self.delete_record(id_)
-
-s = "ins.cryp.sk"
-d = "cryp.sk"
-print(s.replace(f".{d}", ""))
\ No newline at end of file
